@@ -26,28 +26,19 @@ using Cowbell.Base;
 
 namespace Cowbell.Gui
 {
-	public class AboutDialog : GladeWindow
+	public class AboutDialog : GladeDialog
 	{
 		/* public methods */
-		public static void Create ()
-		{
-			new AboutDialog ();
-		}
-
-		public AboutDialog () : base ("AboutDialog.glade", "window")
+		public AboutDialog () : base ("AboutDialog.glade")
 		{
 			/* AppName Version */
 			AppName.Markup = String.Format (Catalog.GetString ("<span weight='bold' size='x-large'>{0} {1}</span>"),
 			                                Globals.AppName, Globals.AppVersion);
 			Image.Pixbuf = new Gdk.Pixbuf (null, "cowbell-48.png");
-			
-			window.Run ();
-			window.Hide ();
 		}
 
 		/* private fields */
 		[Glade.WidgetAttribute] Image Image;
 		[Glade.WidgetAttribute] Label AppName;
-		[Glade.WidgetAttribute] Dialog window;
 	}
 }
